@@ -1,6 +1,7 @@
-from typing import Dict, Any, List, Optional
+from typing import Dict, Optional
 import pandas as pd
 import numpy as np
+import numpy.typing as npt
 from matchms import Spectrum
 import plotly.graph_objects as go
 
@@ -57,7 +58,7 @@ def _set_figure(**kwargs: str) -> go.Figure:
     return fig
 
 
-_DATA_TYPE = Dict[str, np.ndarray]
+_DATA_TYPE = Dict[str, npt.NDArray[np.float64]]
 
 
 def _add_trace(figure: go.Figure, data: _DATA_TYPE, name: str = "") -> None:
@@ -72,6 +73,8 @@ def _add_trace(figure: go.Figure, data: _DATA_TYPE, name: str = "") -> None:
 
 
 def _get_spectrum_data(spectrum: Spectrum) -> _DATA_TYPE:
+    if len(spectrum.peaks.mz) == 0:
+        return {"x": np.array([], dtype="float"), "y": np.array([], dtype="float")}
     df = pd.DataFrame(
         {"intensities": spectrum.peaks.intensities, "mz": spectrum.peaks.mz}
     )
@@ -79,9 +82,15 @@ def _get_spectrum_data(spectrum: Spectrum) -> _DATA_TYPE:
     df["zero"] = 0
     df["mz1"] = df.mz
     df["mz2"] = df.mz
+    x = np.concatenate(  # type: ignore
+        df.loc[:, [f"mz{idx}" for idx in ("", "1", "2")]].values
+    )
+    y = np.concatenate(  # type: ignore
+        df.loc[:, ("zero", "intensities", "blank")].values
+    )
     return {
-        "x": np.concatenate(df.loc[:, [f"mz{idx}" for idx in ("", "1", "2")]].values),
-        "y": np.concatenate(df.loc[:, ("zero", "intensities", "blank")].values),
+        "x": x,
+        "y": y,
     }
 
 
